﻿Option Strict On
Option Explicit On

Imports System
Imports Microsoft.ReportingServices.DataProcessing
Imports Microsoft.ReportingServices.Interfaces

Public Class XmlConnection
    Implements IDbConnection, IDbConnectionExtension
    ' vom Benutzer übergebene Verbindungszeichenfolge
    Private _sVerbindungszeichenfolge As String
    ' Status der Verbindung, standardmäßig geschlossen
    Private _state As System.Data.ConnectionState = System.Data.ConnectionState.Closed
    '---- Implementierung der erforderlichen Eigenschaften
    Private m_integratedSecurity As Boolean = False

    Private m_impersonate As String
    Private m_username As String
    Private m_password As String
    '---- Implementierung der erforderlichen Eigenschaften

    Property IntegratedSecurity() As Boolean _
    Implements IDbConnectionExtension.IntegratedSecurity
        Get
            Return m_integratedSecurity
        End Get
        Set(ByVal value As Boolean)
            m_integratedSecurity = value
        End Set
    End Property

    WriteOnly Property UserName() As String _
    Implements IDbConnectionExtension.UserName
        Set(ByVal value As String)
            m_username = value
        End Set
    End Property

    WriteOnly Property Password() As String Implements _
    IDbConnectionExtension.Password
        Set(ByVal value As String)
            m_password = value
        End Set
    End Property

    WriteOnly Property Impersonate() As String Implements _
    IDbConnectionExtension.Impersonate
        Set(ByVal value As String)
            m_impersonate = value
        End Set
    End Property

    Public Property ConnectionString() As String _
           Implements IDbConnection.ConnectionString
        Get
            ' Zurückgeben, was der Benutzer abgelegt hat.
            Return _sVerbindungszeichenfolge
        End Get
        Set(ByVal Value As String)
            _sVerbindungszeichenfolge = Value
        End Set
    End Property

    Public ReadOnly Property ConnectionTimeout() As Integer _
            Implements IDbConnection.ConnectionTimeout
        Get
            ' Gibt den Verbindungs-Timeout zurück. 
            ' 0 steht für eine unendliche Timeout-Zeit
            Return 0
        End Get
    End Property

    Public ReadOnly Property State() As System.Data.ConnectionState
        Get
            Return _state
        End Get
    End Property
    '---- Implementierung der erforderlichen Methoden

    Public Function BeginTransaction() As IDbTransaction _
            Implements IDbConnection.BeginTransaction
        '-- beginnt eine lokale Transaktion.
        '-- Transaktionen werden in diesem Beispiel nicht unterstützt.
        Throw New NotSupportedException
    End Function 'BeginTransaction

    Public Sub Open() Implements IDbConnection.Open
        '-- Öffnet die Verbindung und merkt sich den Status in interner Variablen. 
        '-- In dieser Implementierung ohne echte Funktionalität
        _state = System.Data.ConnectionState.Open
        Return
    End Sub 'Open

    Public Sub Close() Implements IDbConnection.Close
        '-- Schließt die Verbindung und merkt sich den Status in interner Variablen. 
        '-- In dieser Implementierung ohne echte Funktionalität
        _state = System.Data.ConnectionState.Closed
        Return
    End Sub 'Close

    Public Function CreateCommand() As IDbCommand _
            Implements IDbConnection.CreateCommand
        '-- Gibt eine neue Instanz eines Command-Objekts zurück
        Return New XmlCommand(Me)
    End Function 'CreateCommand

    Public ReadOnly Property LocalizedName() As String _
            Implements IExtension.LocalizedName
        ' –- gibt den lokalisierten Namen des Objekts zurück
        Get
            Return "XML-Datenverarbeitungserweiterung"
        End Get
    End Property

    Public Sub SetConfiguration(ByVal configuration As String) _
            Implements IExtension.SetConfiguration
        ' Kann dazu verwendet werden, Konfigurationsdaten aus Datei zu lesen
    End Sub

    Public Sub Dispose() Implements IDbConnection.Dispose
    End Sub 'Dispose 
End Class 'XmlConnection
